@@ -1,10 +1,11 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2019-2025, by Samuel Williams.
 # Copyright, 2020, by Daniel Evans.
 
 require "async/service/generic"
+require "async/container/supervisor/supervised"
 require "async/http/endpoint"
 
 require_relative "../server"
@@ -52,17 +53,33 @@ module Falcon
 			# @parameter container [Async::Container::Generic]
 			def setup(container)
 				container_options = @evaluator.container_options
+				health_check_timeout = container_options[:health_check_timeout]
 				
 				container.run(name: self.name, **container_options) do |instance|
 					evaluator = @environment.evaluator
 					
 					Async do |task|
-						server = Falcon::Server.new(evaluator.middleware, @bound_endpoint, protocol: @endpoint.protocol, scheme: @endpoint.scheme)
+						if @environment.implements?(Async::Container::Supervisor::Supervised)
+							evaluator.make_supervised_worker(instance).run
+						end
+						
+						server = evaluator.make_server(@bound_endpoint)
 						
 						server.run
 						
 						instance.ready!
 						
+						if health_check_timeout
+							Async(transient: true) do
+								while true
+									# We only update this if the health check is enabled. Maybe we should always update it?
+									instance.name = "#{self.name} (#{server.statistics_string} L=#{Fiber.scheduler.load.round(3)})"
+									sleep(health_check_timeout / 2)
+									instance.ready!
+								end
+							end
+						end
+						
 						task.children.each(&:wait)
 					end
 				end
